@@ -23,10 +23,20 @@ public:
     /**
      * How the list of supported mimetypes can be sorted.
      */
-    enum MimeSortingMode { Unsorted, SortByComment };
+    enum MimeSortingMode {
+        Unsorted,
+        SortByComment
+    };
 
     explicit PluginManager(QObject *parent = nullptr);
 
+    /**
+     * @return The plugin identified by @p pluginId.
+     * The plugin is searched among all the available plugins.
+     * @see availablePlugins
+     */
+    Plugin *pluginById(const QString &pluginId) const;
+
     /**
      * @return The list of all installed plugins.
      * An installed plugin is not necessarily available to the app.
